aboutsummaryrefslogtreecommitdiff
path: root/gas/as.h
diff options
context:
space:
mode:
Diffstat (limited to 'gas/as.h')
-rw-r--r--gas/as.h38
1 files changed, 20 insertions, 18 deletions
diff --git a/gas/as.h b/gas/as.h
index 66d385c..f24b072 100644
--- a/gas/as.h
+++ b/gas/as.h
@@ -1,5 +1,5 @@
/* as.h - global header file
- Copyright (C) 1987, 90, 91, 92, 93, 94, 95, 1996
+ Copyright (C) 1987, 90, 91, 92, 93, 94, 95, 96, 1997
Free Software Foundation, Inc.
This file is part of GAS, the GNU Assembler.
@@ -15,8 +15,9 @@
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
- along with GAS; see the file COPYING. If not, write to
- the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+ along with GAS; see the file COPYING. If not, write to the Free
+ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+ 02111-1307, USA. */
#ifndef GAS
#define GAS 1
@@ -135,6 +136,7 @@ void *alloca ();
#ifdef BFD_ASSEMBLER
#include <bfd.h>
#endif
+#include <libiberty.h>
/* Define the standard progress macros. */
#include <progress.h>
@@ -161,8 +163,8 @@ extern void free ();
extern int errno;
#endif
-/* This is needed for VMS. */
-#if ! defined (HAVE_UNLINK) && defined (HAVE_REMOVE)
+/* This is needed for VMS with DEC C. */
+#if ! defined (__GNUC__) && ! defined (HAVE_UNLINK) && defined (HAVE_REMOVE)
#define unlink remove
#endif
@@ -171,13 +173,6 @@ extern int errno;
#define bcopy(src,dest,size) memcpy(dest,src,size)
#endif
-#ifdef BFD_ASSEMBLER
-/* This one doesn't get declared, but we're using it anyways. This
- should be fixed -- either it's part of the external interface or
- it's not. */
-extern PTR bfd_alloc_by_size_t PARAMS ((bfd *abfd, size_t sz));
-#endif
-
/* Make Saber happier on obstack.h. */
#ifdef SABER
#undef __PTR_TO_INT
@@ -348,11 +343,17 @@ enum _relax_state
constant length frag. */
rs_fill = 1,
- /* Align: Fr_offset: power of 2. Variable chars: fill pattern. */
+ /* Align. The fr_offset field holds the power of 2 to which to
+ align. The fr_var field holds the number of characters in the
+ fill pattern. The fr_subtype field holds the maximum number of
+ bytes to skip when aligning, or 0 if there is no maximum. */
rs_align,
- /* Align code: fr_offset: power of 2. Fill pattern is machine
- specific, defaulting to all zeros. */
+ /* Align code. The fr_offset field holds the power of 2 to which
+ to align. This type is only generated by machine specific
+ code, which is normally responsible for handling the fill
+ pattern. The fr_subtype field holds the maximum number of
+ bytes to skip when aligning, or 0 if there is no maximum. */
rs_align_code,
/* Org: Fr_offset, fr_symbol: address. 1 variable char: fill
@@ -498,6 +499,9 @@ COMMON unsigned char flag_print_statistics;
/* name of emitted object file */
COMMON char *out_file_name;
+/* name of file defining extensions to the basic instruction set */
+COMMON char *insttbl_file_name;
+
/* TRUE if we need a second pass. */
COMMON int need_pass_2;
@@ -541,7 +545,7 @@ typedef struct _pseudo_type pseudo_typeS;
#endif
#ifdef USE_STDARG
-#if __GNUC__ >= 2
+#if (__GNUC__ >= 2) && !defined(VMS)
/* for use with -Wformat */
#define PRINTF_LIKE(FCN) void FCN (const char *format, ...) \
__attribute__ ((format (printf, 1, 2)))
@@ -580,8 +584,6 @@ char *atof_ieee PARAMS ((char *str, int what_kind, LITTLENUM_TYPE * words));
char *input_scrub_include_file PARAMS ((char *filename, char *position));
char *input_scrub_new_file PARAMS ((char *filename));
char *input_scrub_next_buffer PARAMS ((char **bufp));
-PTR xmalloc PARAMS ((unsigned long size));
-PTR xrealloc PARAMS ((PTR ptr, unsigned long n));
int do_scrub_chars PARAMS ((int (*get) (char **), char *to, int tolen));
int gen_to_words PARAMS ((LITTLENUM_TYPE * words, int precision,
long exponent_bits));